import React, { ReactNode, useState } from "react";
import { parse_org } from "../../organic/target/wasm32-unknown-unknown/js/wasm";
import styles from "./OrgAst.module.css";

const OrgAst = (props: { addHighlight: Function; value: string }) => {
  const ast_tree = parse_org(props.value);
  console.log(JSON.stringify(ast_tree));

  if (ast_tree.status !== "success") {
    return <div className={styles.OrgAst}>Error! {ast_tree.content}</div>;
  } else {
    return (
      <div className={styles.OrgAst}>
        <OrgAstNode node={ast_tree.content} />
      </div>
    );
  }
};

const OrgAstNode = (props: { node: any }) => {
  return (
    <div className={styles.OrgAstNode}>
      <div className={styles.OrgAstNodeType}>{props.node["ast-node"]}</div>
      <details>
        <summary>Standard Properties</summary>
        <dl>
          <dt>begin</dt>
          <dd>{props.node["standard-properties"]["begin"]}</dd>
          <dt>contents-begin</dt>
          <dd>{props.node["standard-properties"]["contents-begin"]}</dd>
          <dt>contents-end</dt>
          <dd>{props.node["standard-properties"]["contents-end"]}</dd>
          <dt>end</dt>
          <dd>{props.node["standard-properties"]["end"]}</dd>
          <dt>post-blank</dt>
          <dd>{props.node["standard-properties"]["post-blank"]}</dd>
        </dl>
      </details>
      {Array.isArray(props.node.children) && props.node.children.length > 0 ? (
        <details open={true}>
          <summary>Children</summary>
          <div className={styles.OrgAstChildren}>
            <OrgAstNodeList node_list={props.node.children} />
          </div>
        </details>
      ) : null}
    </div>
  );
};

const OrgAstNodeList = (props: { node_list: any[] }): React.JSX.Element[] => {
  return props.node_list.map((node) => {
    return <OrgAstNode node={node} />;
  });
};

export default OrgAst;
